package com.example.smartlab

import android.os.Bundle
import android.widget.Toast
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.viewModels
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.platform.LocalContext
import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import com.example.smartlab.api.RepositoryImpl
import com.example.smartlab.api.RetrofitInstance
import com.example.smartlab.navigation.Navigation
import com.example.smartlab.ui.theme.SmartLabTheme
import kotlinx.coroutines.flow.collectLatest

class MainActivity : ComponentActivity() {
    val viewModelSmart by viewModels<ViewModelApi>(factoryProducer = {
        object : ViewModelProvider.Factory {
            override fun <T : ViewModel> create(modelClass: Class<T>): T {
                return ViewModelApi(RepositoryImpl(RetrofitInstance.apiSmartLab))
                        as T
            }
        }
    })

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            SmartLabTheme {
                val context = LocalContext.current
                LaunchedEffect(key1 = viewModelSmart.showErrorToastChannel) {
                    viewModelSmart.showErrorToastChannel.collectLatest { show ->
                        if (show) {
                            Toast.makeText(
                                context, "Error", Toast.LENGTH_SHORT
                            ).show()
                        }

                    }
                }
                Navigation(viewModelSmart = viewModelSmart)


            }
        }
    }
}






