package com.example.smartlab

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.smartlab.api.Repository
import kotlinx.coroutines.channels.Channel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.flow.receiveAsFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch

class ViewModelApi(private val repository: Repository): ViewModel() {
    private val _showErrorToastChannel = Channel<Boolean>()
    val showErrorToastChannel = _showErrorToastChannel.receiveAsFlow()
    private val _state = MutableStateFlow<Int?>(null)
    val state = _state.asStateFlow()

    fun sendCodeEmail(email: String) {
        viewModelScope.launch {
            repository.sendCodeEmail(email).collectLatest { result ->
                when (result) {

                    is com.example.smartlab.api.Result.Success -> {

                        _showErrorToastChannel.send(false)


                    }

                    is com.example.smartlab.api.Result.Error -> {
                        _showErrorToastChannel.send(true)
                    }

                }
            }
        }
    }

    fun siqnInEmail(email: String, code: String) {

        viewModelScope.launch {
            repository.signInEmail(email, code).collectLatest { result ->
                when (result) {
                    is com.example.smartlab.api.Result.Error -> {

                        _showErrorToastChannel.send(true)

                        
                    }

                    is com.example.smartlab.api.Result.Success -> {
                        _state.update {1}
                        _showErrorToastChannel.send(false)


                    }
                }
            }

        }

    }

}