package com.example.smartlab.sceens

import Screen
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.interaction.collectIsPressedAsState
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.smartlab.R
import com.example.smartlab.ui.theme.Blue
import com.example.smartlab.ui.theme.SF

@Composable
fun Password(navController: NavController) {
    Box(modifier = Modifier
        .fillMaxSize()
        .background(MaterialTheme.colorScheme.background))
    {
        Row(modifier = Modifier
            .fillMaxWidth(),
            horizontalArrangement = Arrangement.End,
            verticalAlignment = Alignment.Top)
        {
            Text(text = "Пропустить",
                color = Color(0xFF1A6FEE),
                fontSize = 15.sp,
                modifier = Modifier
                    .padding(top = 40.dp, end = 20.dp)
                    .clickable { navController.navigate(Screen.PatientsCard.route) },
                fontFamily = SF,
                fontWeight = FontWeight.Normal)
        }
        Column(modifier = Modifier
            .fillMaxWidth()
            .padding(top = 150.dp),
            horizontalAlignment = Alignment.CenterHorizontally) {
            Text(text = "Создайте пароль", fontSize = 24.sp, fontFamily = SF, fontWeight = FontWeight.Bold, color = MaterialTheme.colorScheme.onBackground)
            Text(text = "Для защиты персональных данных", fontSize = 15.sp, fontFamily = SF, fontWeight = FontWeight.Normal, color = Color(0xFF939396), modifier = Modifier.padding(top = 10.dp))
            Spacer(modifier = Modifier.height(100.dp))

        }


        Column(modifier = Modifier
            .fillMaxSize(),
            verticalArrangement = Arrangement.Bottom) {
            CustomKeyboard(navController)
        }






    }

}


@Composable
fun CustomKeyboard(navController: NavController){
    val inputVal = remember {
        mutableStateOf("")
    }
    CustomKeyboard(inputVal.value,
        onClick = { digit ->
            inputVal.value+=digit.toString()

        }, navController = navController)

}

@Composable
fun CustomKeyboard(
    input:String,
    onClick:(digit:Char)->Unit,
    navController: NavController
)
{
    if(input.length == 4){
        navController.navigate(Screen.PatientsCard.route)
    }
    Column(modifier = Modifier
        .fillMaxWidth()
        .fillMaxHeight(0.6f)
        .padding(bottom = 20.dp),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.SpaceEvenly)
    {
        Row(modifier = Modifier.fillMaxWidth().padding(end= 80.dp, start = 80.dp), horizontalArrangement = Arrangement.SpaceAround){

            repeat(4){it->
                val color = if(input.length > it) Blue else Color.Transparent
                Box (modifier = Modifier
                    .padding(2.dp)
                    .clip(CircleShape)
                    .size(16.dp)
                    .background(color)
                    .border(1.dp, Blue, CircleShape)
                )
            }
        }
        Spacer(modifier = Modifier.height(30.dp))
        Row (modifier = Modifier
            .fillMaxWidth()
            .padding(start = 30.dp, end = 30.dp),
            horizontalArrangement = Arrangement.SpaceAround){
            ButtonCode(number = 1,onClick)
            ButtonCode(number = 2,onClick)
            ButtonCode(number = 3,onClick)

        }
        Row (modifier = Modifier
            .fillMaxWidth()
            .padding(start = 30.dp, end = 30.dp),
            horizontalArrangement = Arrangement.SpaceAround){
            ButtonCode(number = 4,onClick)
            ButtonCode(number = 5,onClick)
            ButtonCode(number = 6,onClick)

        }
        Row (modifier = Modifier
            .fillMaxWidth()
            .padding(start = 30.dp, end = 30.dp),
            horizontalArrangement = Arrangement.SpaceAround){
            ButtonCode(number = 7,onClick)
            ButtonCode(number = 8,onClick)
            ButtonCode(number = 9,onClick)

        }
        Row(modifier = Modifier
            .fillMaxWidth()
            .padding(start = 122.dp, end = 7.dp),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceEvenly)
        {
            ButtonCode(number = 0,onClick)

            Button(onClick = { }, modifier = Modifier.size(80.dp), colors = ButtonDefaults.buttonColors(
                containerColor = MaterialTheme.colorScheme.background,
                contentColor =  MaterialTheme.colorScheme.onBackground)) {
                Icon(painter = painterResource(id = R.drawable.delete), contentDescription = null, modifier = Modifier.size(80.dp))

            }
        }
        Spacer(modifier = Modifier.height(20.dp))

    }

}

@Composable
fun ButtonCode(number: Int, onClick:(digit:Char)->Unit)
{
    val interactionSource = remember { MutableInteractionSource() }
    val isPressed by interactionSource.collectIsPressedAsState()
    val colorConteiner = if (isPressed) Color(0xFF1A6FEE) else Color(0xFFF5F5F9)
    val colorContent = if (isPressed) Color.White else Color.Black
    Box(modifier = Modifier
        .clip(RoundedCornerShape(80.dp)))
    {
        Button(onClick = {
         onClick(number.digitToChar())
        },
            interactionSource = interactionSource,
            modifier= Modifier
                .size(80.dp),
            shape = CircleShape,
            colors = ButtonDefaults.buttonColors(
                containerColor = colorConteiner,
                contentColor = colorContent
            )
        ) {
            Text(text = number.toString(),  fontSize = 24.sp, fontFamily = SF, fontWeight = FontWeight.SemiBold)
        }
    }

}
